#include "wr-dio-regs_v2.h"

/* We need a clear mapping for the registers of the various bits */
struct regmap {
	int trig_l;
	int trig_h;
	int cycle;
	int pulse;
	int pulse_per;
	int fifo_tai_l;
	int fifo_tai_h;
	int fifo_cycle;
	int fifo_status;
};

struct regmap_common {
	int ver_;
	int iomode_reg;
	int latch_reg;
	int trig_reg;
	int pulse_reg;
	int eic_idr_reg;
	int eic_ier_reg;
	int eic_imr_reg;
	int eic_isr_reg;
};

#define R(x) (offsetof(struct DIO_WB, x))
struct regmap regmap_v2[] = {
	{
		.trig_l = R(TRIG0), //0
		.trig_h = R(TRIGH0),//4
		.cycle = R(CYC0),//8
		.pulse = R(PROG0_PULSE),//C
		.pulse_per = R(PROG0_PULSE_PER),//10
		.fifo_tai_l = R(TSF0_R0),//14
		.fifo_tai_h = R(TSF0_R1),//18
		.fifo_cycle = R(TSF0_R2),//20
		.fifo_status = R(TSF0_CSR),//24
	}, {
		.trig_l = R(TRIG1),//28
		.trig_h = R(TRIGH1),//2C
		.cycle = R(CYC1),//30
		.pulse = R(PROG1_PULSE),//34
		.pulse_per = R(PROG1_PULSE_PER),
		.fifo_tai_l = R(TSF1_R0),
		.fifo_tai_h = R(TSF1_R1),
		.fifo_cycle = R(TSF1_R2),
		.fifo_status = R(TSF1_CSR),
	}, {
		.trig_l = R(TRIG2),
		.trig_h = R(TRIGH2),
		.cycle = R(CYC2),
		.pulse = R(PROG2_PULSE),
		.pulse_per = R(PROG2_PULSE_PER),
		.fifo_tai_l = R(TSF2_R0),
		.fifo_tai_h = R(TSF2_R1),
		.fifo_cycle = R(TSF2_R2),
		.fifo_status = R(TSF2_CSR),
	}, {
		.trig_l = R(TRIG3),
		.trig_h = R(TRIGH3),
		.cycle = R(CYC3),
		.pulse = R(PROG3_PULSE),
		.pulse_per = R(PROG3_PULSE_PER),
		.fifo_tai_l = R(TSF3_R0),
		.fifo_tai_h = R(TSF3_R1),
		.fifo_cycle = R(TSF3_R2),
		.fifo_status = R(TSF3_CSR),
	}, {
		.trig_l = R(TRIG4),
		.trig_h = R(TRIGH4),
		.cycle = R(CYC4),
		.pulse = R(PROG4_PULSE),
		.pulse_per = R(PROG4_PULSE_PER),
		.fifo_tai_l = R(TSF4_R0),
		.fifo_tai_h = R(TSF4_R1),
		.fifo_cycle = R(TSF4_R2),
		.fifo_status = R(TSF4_CSR),
	}, {
		.trig_l = R(TRIG5),
		.trig_h = R(TRIGH5),
		.cycle = R(CYC5),
		.pulse = R(PROG5_PULSE),
		.pulse_per = R(PROG5_PULSE_PER),
		.fifo_tai_l = R(TSF5_R0),
		.fifo_tai_h = R(TSF5_R1),
		.fifo_cycle = R(TSF5_R2),
		.fifo_status = R(TSF5_CSR),
	}
};

struct regmap_common regmap_common_v2 = 
{
	.ver_ = R(VER),
	.iomode_reg = R(IOMODE),
	.latch_reg = R(R_LATCH),
	.trig_reg = R(TRIG),
	.pulse_reg = R(PULSE),
	.eic_idr_reg = R(EIC_IDR),
	.eic_ier_reg = R(EIC_IER), 
	.eic_imr_reg = R(EIC_IMR),
	.eic_isr_reg = R(EIC_ISR),
};
